#!/bin/bash

set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
HOST_WORKSPACE_PATH="${HOST_WORKSPACE_PATH:-$(pwd)}"

echo "--------------------------------"
echo "PWD:                 $(pwd)"
echo "SCRIPT_DIR:          $SCRIPT_DIR"
echo "GITHUB_WORKSPACE:    ${GITHUB_WORKSPACE:-not set}"
echo "HOST_WORKSPACE_PATH: $HOST_WORKSPACE_PATH"
echo "JOB_CONTAINER_NAME:  ${JOB_CONTAINER_NAME:-not set}"
echo "--------------------------------"
echo "--------------------------------"
echo "--------------------------------"
echo "Docker info:"
docker info | grep -E "(Docker Root Dir|Storage Driver)" || true
echo "Mount info:"
mount | grep -E "(overlay|workspace)" || true

echo "--------------------------------"
echo "--------------------------------"
echo "--------------------------------"
echo "ls on host"
ls -la ./

# Check if we're running in Gitea Actions
if [ -n "${JOB_CONTAINER_NAME:-}" ]; then
    echo "--------------------------------"
    echo "Running in Gitea Actions - using --volumes-from"
    echo "--------------------------------"
    
    echo "ls -la using --volumes-from"
    docker run --rm -i --entrypoint /bin/bash \
        --volumes-from="${JOB_CONTAINER_NAME}" \
        debian:latest -c "cd ${GITHUB_WORKSPACE} && ls -la"
    
    echo "--------------------------------"
    echo "Test file creation and reading"
    echo "Creating test file in action container..."
    echo "This is a test file from Gitea Actions" > test-file.txt
    
    echo "Reading test file from Docker container..."
    docker run --rm -i --entrypoint /bin/bash \
        --volumes-from="${JOB_CONTAINER_NAME}" \
        debian:latest -c "cd ${GITHUB_WORKSPACE} && cat test-file.txt"
    
    # Clean up
    rm -f test-file.txt
else
    echo "--------------------------------"
    echo "Running locally - using direct volume mounts"
    echo "--------------------------------"
    
    echo "ls -la ./"
    docker run --rm -i --entrypoint /bin/bash -v ./:/workspace debian:latest -c "ls -la /workspace"
    echo "--------------------------------"
    echo "ls -la \$PWD"
    docker run --rm -i --entrypoint /bin/bash -v "$PWD:/workspace" debian:latest -c "ls -la /workspace"
    echo "--------------------------------"
    echo "ls -la \$SCRIPT_DIR"
    docker run --rm -i --entrypoint /bin/bash -v "$SCRIPT_DIR:/workspace" debian:latest -c "ls -la /workspace"
fi

echo "--------------------------------"

MOUNT_DIR="$SCRIPT_DIR"
if [ -n "${HOST_WORKSPACE_PATH:-}" ]; then
    MOUNT_DIR=$(echo "$SCRIPT_DIR" | sed "s|^/workspace|$HOST_WORKSPACE_PATH|")
    if [ "$MOUNT_DIR" != "$SCRIPT_DIR" ]; then
        echo "Docker-in-Docker: Mapping $SCRIPT_DIR to $MOUNT_DIR"
    fi
fi

echo "MOUNT_DIR: $MOUNT_DIR"
echo "ls -la \$MOUNT_DIR"
docker run --rm -i --entrypoint /bin/bash -v "$MOUNT_DIR:/workspace" debian:latest -c "ls -la /workspace"

echo "--------------------------------"

